@@ -7,7 +7,7 @@ consistent input vs output interface for transformations on db entries.
 
 from __future__ import division
 
-__author__ = "Shyue Ping Ong"
+__author__ = "Shyue Ping Ong, Will Richards"
 __copyright__ = "Copyright 2012, The Materials Project"
 __version__ = "1.0"
 __maintainer__ = "Shyue Ping Ong"
@@ -16,13 +16,15 @@ __date__ = "Mar 2, 2012"
 
 import os
 import re
-import datetime
 import json
+import collections
+import datetime
 
 from pymatgen.core.structure import Structure
+from pymatgen.transformations.standard_transformations import transformation_from_dict
 from pymatgen.io.cifio import CifParser
 from pymatgen.io.vaspio import Poscar
-from pymatgen.transformations.standard_transformations import transformation_from_dict
+from copy import deepcopy
 
 class TransformedStructure(object):
     """
@@ -32,7 +34,7 @@ class TransformedStructure(object):
     transformation history.
     """
 
-    def __init__(self, structure, transformations, history = None):
+    def __init__(self, structure, transformations, history = None, other_parameters = None):
         """
         Standard constructor for a TransformedStructure
         
@@ -45,17 +47,24 @@ class TransformedStructure(object):
                 optional history for the input structure, which provides a way
                 to track structures having undergone multiple series of 
                 transformations.
+            other_parameters:
+                optional parameters to store along with the transformedstructure.
+                This can include tags (a list) or author which will be parsed when the structure
+                is uploaded to the database
         """
         history = [] if history == None else history
         self._source = {}
         self._structures = []
         self._transformations = []
+        self._transformation_parameters = []
         self._redo_trans = []
+        self._other_parameters = {} if other_parameters == None else deepcopy(other_parameters)
         if len(history) > 0:
             self._source = history[0]
             for i in xrange(1, len(history)):
                 self._structures.append(Structure.from_dict(history[i]['input_structure']))
                 self._transformations.append(transformation_from_dict(history[i]))
+                self._transformation_parameters.append(history[i].get('output_parameters', {}))
 
         self._structures.append(structure)
         for t in transformations:
@@ -71,6 +80,7 @@ class TransformedStructure(object):
         if len(self._transformations) == 0:
             raise IndexError("Can't undo. Already at oldest change.")
         self._structures.pop()
+        self._transformation_parameters.pop()
         self._redo_trans.append(self._transformations.pop())
 
     def redo_next_transformation(self):
@@ -83,19 +93,32 @@ class TransformedStructure(object):
         if len(self._redo_trans) == 0:
             raise IndexError("Can't undo. Already at latest change.")
         t = self._redo_trans.pop()
-        self.append_transformation(t, False)
+        self.append_transformation(t, clear_redo = False)
 
     def __getitem__(self, index):
         return (self._structures[index], self._transformations[0:index])
 
+    def __getattr__(self, name):
+        return getattr(self._structures[-1], name)
+
     def __len__(self):
         return len(self._structures)
 
-    def append_transformation(self, transformation, clear_redo = True):
+    @staticmethod
+    def _alternative_transformed_structures(unmodified_transformed_structure, transformation, structure_dicts):
+        for x in structure_dicts:
+            new_structure = deepcopy(unmodified_transformed_structure)
+            new_structure._structures.append(x.pop('structure'))
+            new_structure._transformation_parameters.append(x)
+            new_structure._transformations.append(transformation)
+            yield new_structure
+
+
+    def append_transformation(self, transformation, return_alternatives = False, clear_redo = True):
         """
         Appends a transformation to the TransformedStructure.
         
-        Arguments:
+        Args:
             transformation:
                 Transformation to append
             clear_redo:
@@ -104,9 +127,23 @@ class TransformedStructure(object):
                 However, when using append_transformation to do a redo, the redo
                 list should not be cleared to allow multiple redos.
         """
-        new_s = transformation.apply_transformation(self._structures[-1])
-        self._structures.append(new_s)
-        self._transformations.append(transformation)
+
+        if return_alternatives:
+            structures_dict_list = transformation.apply_transformation(self._structures[-1], return_ranked_list = True)
+            alternative_structures = self._alternative_transformed_structures(deepcopy(self), transformation, structures_dict_list[1:])
+
+            new_s = structures_dict_list[0]
+            self._structures.append(new_s.pop('structure'))
+            self._transformations.append(transformation)
+            self._transformation_parameters.append(new_s)
+            return alternative_structures
+
+        else:
+            new_s = transformation.apply_transformation(self._structures[-1])
+            self._structures.append(new_s)
+            self._transformation_parameters.append({})
+            self._transformations.append(transformation)
+
         if clear_redo:
             self._redo_trans = []
 
@@ -114,7 +151,7 @@ class TransformedStructure(object):
         """
         Extends a sequence of transformations to the TransformedStructure.
         
-        Arguments:
+        Args:
             transformations:
                 Sequence of Transformations
         """
@@ -163,10 +200,29 @@ class TransformedStructure(object):
         output.append(str(self._source))
         output.append("\nTransformation history")
         output.append("------------")
-        for t in self._transformations:
-            output.append(str(t.to_dict))
+        for i, t in enumerate(self._transformations):
+            output.append(str(t.to_dict) + ' ' + str(self._transformation_parameters[i]))
+        output.append("\nOther parameters")
+        output.append("------------")
+        output.append(str(self._other_parameters))
         return "\n".join(output)
 
+    def set_parameter(self, key, value):
+        self._other_parameters[key] = value
+
+    @property
+    def other_parameters(self):
+        return self._other_parameters
+
+    @property
+    def was_modified(self):
+        """
+        boolean describing whether the last transformation on the structure made any alterations to it
+        one example of when this would return false is in the case of performing a substitution transformation
+        on the structure when the specie to replace isn't in the structure.
+        """
+        return not self._structures[-1] == self._structures[-2]
+
     @property
     def structures(self):
         """
@@ -195,7 +251,17 @@ class TransformedStructure(object):
         Creates a TransformedStructure from a dict.
         """
         s = Structure.from_dict(d)
-        return TransformedStructure(s, [], d['history'])
+        return TransformedStructure(s, [], d['history'], d.get('other_parameters', None))
+
+    @property
+    def history(self):
+        history = [self._source]
+        for i, t in enumerate(self._transformations):
+            tdict = t.to_dict
+            tdict['input_structure'] = self._structures[i].to_dict
+            tdict['output_parameters'] = self._transformation_parameters[i]
+            history.append(tdict)
+        return history
 
     @property
     def to_dict(self):
@@ -203,23 +269,16 @@ class TransformedStructure(object):
         Returns a dict representation of the TransformedStructure.
         """
         d = self._structures[-1].to_dict
-        history = [self._source]
-        for i, t in enumerate(self._transformations):
-            tdict = t.to_dict
-            tdict['input_structure'] = self._structures[i].to_dict
-            history.append(tdict)
-        d['history'] = history
+        d['history'] = self.history
         d['version'] = __version__
+        d['other_parameters'] = self._other_parameters
         return d
 
-
-class CifTransformedStructure(TransformedStructure):
-    """
-    Extended version of TransformedStructure to generates new materials from cifs.
-    """
-
-    def __init__(self, cif_string, transformations, primitive = True):
+    @staticmethod
+    def from_cif_string(cif_string, transformations = [], primitive = True):
         """
+        Generates TransformedStructure from a cif string.
+
         Args:
             cif_string:
                 Input cif string. Should contain only one structure. For cifs
@@ -244,21 +303,16 @@ class CifTransformedStructure(TransformedStructure):
         else:
             source = 'uploaded cif'
         source_info = {'source':source, 'datetime':str(datetime.datetime.utcnow()), 'original_file':raw_string, 'cif_data':cif_dict[cif_keys[0]]}
-        super(CifTransformedStructure, self).__init__(s, transformations, [source_info])
+        return TransformedStructure(s, transformations, [source_info])
 
-
-class PoscarTransformedStructure(TransformedStructure):
-    """
-    Generates a transformed structure from Poscar.
-    """
-
-    def __init__(self, poscar_string, transformations):
+    @staticmethod
+    def from_poscar_string(poscar_string, transformations = []):
         """
+        Generates TransformedStructure from a poscar string. 
+
         Args:
             poscar_string:
                 Input POSCAR string.
-            transformations:
-                Sequence of transformations to be applied to the input structure.
         """
         p = Poscar.from_string(poscar_string)
         if not p.true_names:
@@ -266,5 +320,6 @@ class PoscarTransformedStructure(TransformedStructure):
         raw_string = re.sub("'", "\"", poscar_string)
         s = p.struct
         source_info = {'source': "uploaded POSCAR", 'datetime':str(datetime.datetime.utcnow()), 'original_file':raw_string}
-        super(PoscarTransformedStructure, self).__init__(s, transformations, [source_info])
+        return TransformedStructure(s, transformations, [source_info])
+
 
