@@ -22,6 +22,7 @@ import abc
 import ConfigParser
 import json
 
+from pymatgen.core.periodic_table import Element
 from pymatgen.io.vaspio import Incar, Poscar, Potcar, Kpoints
 
 class AbstractVaspInputSet(object):
@@ -143,19 +144,31 @@ class VaspInputSet(AbstractVaspInputSet):
 
     def get_incar(self, structure):
         incar = Incar()
+        comp = structure.composition
         poscar = Poscar(structure)
         for key, setting in self.incar_settings.items():
             if key == "MAGMOM":
                 incar[key] = [setting.get(site.specie.symbol, 0.6) for site in structure]
             elif key in ['LDAUU', 'LDAUJ', 'LDAUL']:
-                incar[key] = [setting.get(sym, 0) for sym in poscar.site_symbols]
+                if comp[Element("O")] > 0 or comp[Element("F")] > 0:
+                    incar[key] = [setting.get(sym, 0) for sym in poscar.site_symbols]
+                else:
+                    incar[key] = [0 for sym in poscar.site_symbols]
             elif key == "EDIFF":
                 incar[key] = float(setting) * structure.num_sites
             else:
                 incar[key] = setting
 
         has_u = ("LDAUU" in incar and sum(incar['LDAUU']) > 0)
-        if not has_u:
+        if has_u:
+            # modify LMAXMIX if LSDA+U and you have d or f electrons
+            # note that if the user explicitly sets LMAXMIX in settings it will override this logic
+            if 'LMAXMIX' not in self.incar_settings.keys():
+                if any([el.Z > 56 for el in structure.composition]):  # contains f-electrons
+                    incar['LMAXMIX'] = 6
+                elif any([el.Z > 20 for el in structure.composition]):  # contains d-electrons
+                    incar['LMAXMIX'] = 4
+        else:
             for key in incar.keys():
                 if key.startswith('LDAU'):
                     del incar[key]
